<?php
/** Līvõ kēļ (Līvõ kēļ)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Ohpuu
 * @author Warbola
 */

$fallback = 'et';

$messages = array(
# Dates
'sunday'        => 'pivāpǟva',
'monday'        => 'ežžõmpǟva',
'tuesday'       => 'tūoiznapǟva',
'wednesday'     => 'kuolmõndpǟva',
'thursday'      => 'neļļõndpǟva',
'friday'        => 'brēḑig',
'saturday'      => 'pūolpǟva',
'sun'           => 'Piv',
'mon'           => 'Ežž',
'tue'           => 'Tūo',
'wed'           => 'Kuo',
'thu'           => 'Neļ',
'fri'           => 'Brē',
'sat'           => 'Pūo',
'january'       => 'janvār',
'february'      => 'februār',
'march'         => 'märts',
'april'         => 'april',
'may_long'      => 'maij',
'june'          => 'jūnij',
'july'          => 'jūlij',
'august'        => 'august',
'september'     => 'septembõr',
'october'       => 'oktōbõr',
'november'      => 'novembõr',
'december'      => 'detsembõr',
'january-gen'   => 'Janvār',
'february-gen'  => 'Februār',
'march-gen'     => 'Märts',
'april-gen'     => 'April',
'may-gen'       => 'Maij',
'june-gen'      => 'Jūnij',
'july-gen'      => 'Jūlij',
'august-gen'    => 'August',
'september-gen' => 'Septembõr',
'october-gen'   => 'Oktōbõr',
'november-gen'  => 'Novembõr',
'december-gen'  => 'Detsembõr',
'jan'           => 'jan',
'feb'           => 'feb',
'mar'           => 'mär',
'apr'           => 'apr',
'may'           => 'maij',
'jun'           => 'jūnij',
'jul'           => 'jūlij',
'aug'           => 'aug',
'sep'           => 'sept',
'oct'           => 'okt',
'nov'           => 'nov',
'dec'           => 'dets',

# Categories related messages
'pagecategories'         => '{{PLURAL:$1|Kategōrij|Kategōrijõd}}',
'category_header'        => 'Lēḑõd kategōrijs "$1"',
'subcategories'          => 'Allizt Kategōrijd',
'category-media-header'  => 'Mēdij failõd kategōrijs "$1"',
'category-empty'         => 'Sīesõ kategōrijs äb ūo mitīd līedpūoltõ äbkā mēdij-failõ',
'hidden-categories'      => '{{PLURAL:$1|Jarā vaŗtõd kategōrij|Jarā vaŗtõd kategōrijõd}}',
'category-subcat-count'  => '{{PLURAL:$2|Sīesõ kategōrijs um setku se alli kategōrij.|Sīesõ kategōrijs ātõ  {{PLURAL:$1|alli kategōrij|$1 alīzt kategōrijõ}}, kubsõ $2.}}',
'category-article-count' => '{{PLURAL:$2| Andtõd kategōrijs um setku se lēḑ.|{{PLURAL:$1|Se lēḑ| Ne $1 līedtõ ātõ}} sīesõ kategōrijs ( kubsõ) $2.}}',
'category-file-count'    => '{{PLURAL:$2| Andtõd kategōrijs um setku se lēḑ.|{{PLURAL:$1|Se lēḑ| Ne $1 līedtõ ātõ}} sīesõ kategōrijs ( kubsõ) $2.}}',
'listingcontinuesabbrev' => 'jatk.',
'noindex-category'       => 'Lēḑõd bäz indeksõ',

'about'      => 'Titõl-tīetõkst',
'newwindow'  => '(lǟb vāldiž ūdsõ läbūs)',
'cancel'     => ' Kitõgid jarā',
'mytalk'     => 'Nõvpidāmi',
'navigation' => 'Navigīerimi',

# Cologne Blue skin
'qbfind' => 'Vȯtšõgid',
'faq'    => 'SKK',

# Vector skin
'vector-action-addsection' => 'Pangid jūrõ tēma',
'vector-action-delete'     => 'Kištāntõgid jarā',
'vector-action-move'       => 'Vīž jarā',
'vector-action-protect'    => 'Kaitsõmi',
'vector-view-create'       => 'Lūo',
'vector-view-edit'         => 'Redigīer',
'vector-view-history'      => 'Nägţ istōrijõ',
'vector-view-view'         => 'Vaņ',
'vector-view-viewsource'   => 'Vaņ ovāt tekstõ',
'actions'                  => 'Tīemizt',
'namespaces'               => 'Nim-rūimõd',
'variants'                 => 'Varianţõd',

'errorpagetitle'   => 'Vigā',
'returnto'         => 'Li tāgiž līed $1 jūrõ.',
'tagline'          => 'Ovāt: {{SITENAME}}',
'help'             => 'Opātõks',
'search'           => 'Vȯtšimi',
'searchbutton'     => 'Vȯtšimi',
'searcharticle'    => 'Li',
'history'          => 'Kēratõks istōrij',
'history_short'    => 'Istōrij',
'printableversion' => 'Drukkimiz versij',
'permalink'        => 'Iggi siḑīm',
'edit'             => 'Redigīer',
'create'           => 'Lūo',
'editthispage'     => 'Redigīer siedā līedtõ',
'delete'           => 'Kištāntõgid jarā',
'protect'          => 'Kaitsõmi',
'protect_change'   => 'mõitiņt',
'newpage'          => 'Ūž lēḑ',
'talkpage'         => 'Sīe kēratõks nõvpidāmi',
'talkpagelinktext' => 'Nõvpidāmi',
'personaltools'    => 'Ummizt tīeažād',
'talk'             => 'Nõvpidāmi',
'views'            => 'vaņtlimiži',
'toolbox'          => 'Tīeažād',
'otherlanguages'   => 'Mūši kīelši',
'redirectedfrom'   => '(Jeddõpēḑõn sōtõd līedstõ $1)',
'redirectpagesub'  => 'Jeddõpēḑõn sōtimiz lēḑ',
'lastmodifiedat'   => 'Perri mõitiņtimi: $2 $1',
'jumpto'           => 'Li:',
'jumptonavigation' => 'navigīerimiz kast',
'jumptosearch'     => 'Vȯtšõgid',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Iļ {{SITENAME}}',
'aboutpage'            => 'Project:Tītõl tieutõkst',
'copyright'            => 'Amā tekstõ um kȭlbatõmist litsents #$1 pierrõ',
'copyrightpage'        => '{{ns:project}}:Autorõigõmt',
'currentevents'        => 'Suggimizt',
'currentevents-url'    => 'Project:Suggimizt',
'disclaimers'          => 'Kūondõkst',
'disclaimerpage'       => 'Project:Kūondõkst',
'edithelp'             => 'Redigīerimiz opātõks',
'edithelppage'         => 'Help:Redigīerimiz_opātõks',
'helppage'             => 'Help:Sižāli',
'mainpage'             => 'Eḑḑilēḑ',
'mainpage-description' => 'Eḑḑilēḑ',
'portal'               => 'Kubgõnd vǟrõd',
'portal-url'           => 'Project:Kubgõnd vǟrõd',
'privacy'              => 'Privātõm',
'privacypage'          => 'Project:Privātõm',

'badaccess' => 'Õigõm pūtõb',

'retrievedfrom'       => 'Ulzõ vȯtštõd "$1"',
'youhavenewmessages'  => 'Täddõn um $1 ($2)',
'newmessageslink'     => 'ūži tīeūţidi',
'newmessagesdifflink' => 'perri mõitõks',
'editsection'         => 'redigīer',
'editold'             => 'redigīerõgid',
'viewsourceold'       => 'vaņ ovāt-tekstõ',
'editlink'            => 'redigīerõgid',
'viewsourcelink'      => 'vaņ ovāt-tekstõ',
'editsectionhint'     => 'Redigīer jaggõ $1',
'toc'                 => 'Sižāli',
'showtoc'             => 'nägţõgid',
'hidetoc'             => 'vōrõgid jarā',
'site-rss-feed'       => '$1 RSS sīeţ',
'site-atom-feed'      => '$1 Atom sīeţ',
'page-rss-feed'       => '"$1" RSS sīeţ',
'page-atom-feed'      => '"$1" Atom sīeţ',
'red-link-title'      => '$1 äb ūo vel kēratõd',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'     => 'Kēratõks',
'nstab-user'     => 'Kȭlbatijiz lēḑ',
'nstab-special'  => 'Eņtšvīţi lēḑ',
'nstab-project'  => 'Projekt lēḑ',
'nstab-image'    => 'Bīlda',
'nstab-template' => 'Mall',
'nstab-category' => 'Kategōrij',

# General errors
'missing-article'    => " Datubāz äb lieudõn kizdõd līed ''$1'' $2 tekstõ. Sīkõks võib vȱlda mõitõkst agā istōrij siḑīm jarā kištāntõd lēḑ pǟlõ.  Až ažād äb ūo nei,  võib vȱlda ka vigā sistēms. Siz um kītõmõst ka [[Special:ListUsers/sysop| administrātorõn]] ja tämmõn āndamizt ka sīe līed internet adres",
'missingarticle-rev' => '(redaktsij: $1)',
'badtitle'           => 'Vigāli pēļikēra',
'badtitletext'       => 'Tōdõd līed pēļikēra vȯļ vigāli, tijā agā tuoizõst kīel versiōnist agā vikist äbõigistiz sidtõd. Sīe sizzõl võib vȱlda ikš agā jemīņ simbōlõ, midā äb sō pēļikēris kȭlbatõ.',
'viewsource'         => 'Vaņ ovāt tekstõ',

# Login and logout pages
'yourname'                => 'Kȭlbatijiznim:',
'yourpassword'            => 'Sallisõnä:',
'yourpasswordagain'       => 'Kēratigid sallisõnā ūtstõ:',
'remembermypassword'      => ' Mǟdlõgid sallisõnā (kuņtš $1 {{PLURAL:$1|päuvõ|päuvõ}})',
'login'                   => 'Log sīezõ',
'nav-login-createaccount' => 'Log sīezõ agā registrīer kȭlbatijizõks',
'loginprompt'             => "Sīezõ loggimizõks täddõn um āndamizt lubā \"kūkid\" (''cookies'') pierāst",
'userlogin'               => 'Sīezõ loggimi agā kȭlbatijiz-konto lūomi',
'logout'                  => 'Log ulzõ',
'userlogout'              => 'Log ulzõ',
'nologin'                 => "Až täddõn äb ūo eņtš konto, '''$1'''.",
'nologinlink'             => 'Registrīerõgid täs',
'createaccount'           => 'Lūogid ūž konto',
'gotaccount'              => "Až täddõn jubā um eņtš konto, '''$1'''.",
'gotaccountlink'          => 'Log sīezõ',
'userlogin-resetlink'     => 'Kas tēg unīztõ jarā eņtš sizzõlkēratimiz tīetõkst?',
'mailmypassword'          => 'Sōtõgid e-kēras ūž sallisõnā',
'loginlanguagelabel'      => 'Kēļ: $1',

# Edit page toolbar
'bold_sample'     => 'Razzi kēra',
'bold_tip'        => 'Razzi kēra',
'italic_sample'   => 'Slīp kēra',
'italic_tip'      => 'Slīp kēra',
'link_sample'     => 'Sidtõb pēļikēra',
'link_tip'        => 'Sizāļi siḑīm',
'extlink_sample'  => 'http://www.example.com siḑīm nim',
'extlink_tip'     => 'Uļļi siḑīm (algid undõgid ku um vȯlmizt  http:// prefiks)',
'headline_sample' => 'Pēļikēra',
'headline_tip'    => 'Ildõm 2 pēļikēra',
'nowiki_sample'   => 'Kēratigid tǟnõ tekstõ bäz formātõ',
'nowiki_tip'      => 'Bäz vikipēdij formātõ',
'image_tip'       => 'Sidtõb bildā',
'media_tip'       => 'Siḑīm fail jūrõ',
'sig_tip'         => 'Sin allikēra āiga-spīedolõks',
'hr_tip'          => 'Horizontāli krīpš (kȭlbatõgid bäz tērõmizt)',

# Edit pages
'summary'                          => 'Kubbõ võtāmi:',
'subject'                          => 'Pēļikēra:',
'minoredit'                        => 'Se um ikš piški parāmtimi',
'watchthis'                        => 'Vaņ iļ siedā līedpūoltõ',
'savearticle'                      => 'Sa-gläbbõmi',
'preview'                          => 'Jedmõl-vaņtlimi',
'showpreview'                      => 'Nägţ jeddõl vaņtlimizt',
'showdiff'                         => 'Nägţ mõitõkši',
'anoneditwarning'                  => "'''Kūondõks:''' Sa äb ūo sīezõ logtõd. Sin IP adres sa-gläbūbõd sīe līed redigīerimiz loggõs.",
'summary-preview'                  => 'Rezimē jedmõl-vaņtlimi:',
'newarticle'                       => '(Ūž)',
'newarticletext'                   => "Līedtõ, kus siḑīm sīnda vīž, äb ūo vel. 
Līedpūol lūomizõks täddõn um tǟnõ alīzõ kastõz kēratimist (mū tieut [[{{MediaWiki:Helppage}}|opātõksõst]]). 
Až jutīztõ tǟnõ mõţmõt, glõbž brauzer '''tāgiž''' - knīepkiz pǟlõ.",
'noarticletext'                    => 'Sīesõ līeds paldīž tekstõ äb ūo.
Sa võid [[Special:Search/{{PAGENAME}}|vȯtšõ pēļizkēra frāzõ]] mūšti lēḑist,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} vȯtšõ tämstõ log failidi],
agā [{{fullurl:{{FULLPAGENAME}}|action=edit}} sīe līed īž lūodõ]</span>.',
'noarticletext-nopermission'       => 'Sīesõ līeds paldīž tekstõ äb ūo.
Sa võid [[Special:Search/{{PAGENAME}}|vȯtšõ pēļizkēra frāzõ]] mūšti lēḑist,
<span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} vȯtšõ tämstõ log failidi],
agā [{{fullurl:{{FULLPAGENAME}}|action=edit}} sīe līed īž lūodõ]</span>.',
'previewnote'                      => "''' Algid undõgid, ku se um setku jedmõl-vaņtlimi!'''
Sin redigīerimizt äb ūo vel sa-gläbdõd !",
'editing'                          => 'Redigīerimiz pǟl um $1',
'editingsection'                   => 'Redigīerimiz pǟl um $1 sektsij līedst',
'copyrightwarning'                 => "Pidāgid mīelsõ, ku amā täd kubsõtīe võrgõ-pāikal {{SITENAME}} luggõbõd ulzõ andtõd litsents $2 allõ (vaņ ka $1). Až tēg äb tō, ku täd kēratõd tekstõ bäz zǟlõmizt redigīerõbõd ja eņtš jarā-nēmiz pierrõ kȭlbatõbõd, siz algid siedā tǟnõ sa-gläbbõgid. <br />
Tēg tȭitat ka, ku kēratiztõ sīe īž agā võtīztõ sīe ovātõst, kust kopierimi äb ūo kīeldtõd. <br /> 
'''Algid sōtõgid autorõigõmtõks kaitstõd materiālidi bäz lubbõ!'''",
'templatesused'                    => 'Sīesõ līeds um kȭlbatõd {{PLURAL:$1|se mall|ne mallõd}} :',
'templatesusedpreview'             => 'Jedmõl-vaņtlimizõs {{PLURAL:$1|kȭlbatõb mall|kȭlbatõbõd mallõd}} :',
'template-protected'               => '(kaitstõd)',
'template-semiprotected'           => '(ikš rōz kaitstõd)',
'hiddencategories'                 => 'This page is a member of {{PLURAL:$1|1 hidden category|$1 hidden categories}}:
Se lēḑ um {{PLURAL:$1|īds jarā vaŗtõd kategōrijõs|$1 jarā vaŗtõd kategōrijõs }}:',
'permissionserrorstext-withaction' => 'Sinnõn äb ūo õigõmt $2 {{PLURAL:$1||}} pierāst:',
'recreate-moveddeleted-warn'       => "'''Kūondõks: Tōtõ lūodõ ūtstõ līedpūoltõ, mis um jo vārald jarā kištāntõd.'''
Mõtlõgid, kas līed ūtstõ lūomi um jõvā mõtk. Līed jedmõlizt jarā kištāntimizt ja jarā-vīmizt :",
'moveddeleted-notice'              => 'Se lēḑ um jarā kištāntõd. Allõ-pūol um nägţõd līed jarā kištāntimiz ja jarā vīmiz.log.',

# Parser/template warnings
'post-expand-template-inclusion-warning'  => "'''Kūondõks:''' Kizdõd mallõd lug um pa-jennõks sūr. Mingiži mallidi äb sō nägţõ.",
'post-expand-template-inclusion-category' => 'Lēḑõd, kus um mallõd limīt täuž',
'post-expand-template-argument-warning'   => "'''' Kūondõks:''' Se lēḑ sizzõl um amā veitõ umīţõgid ikš mall argument, mis um pa-jennõks sūr. Ne argumentõd um ulzõ jettõd.",
'post-expand-template-argument-category'  => 'Lēḑõd missõs ātõ mall pūtõbõd argumentõd',

# History pages
'viewpagelogs'           => 'Vaņ sīe līed logīdi',
'currentrev-asof'        => 'Perri redaktsij: $1',
'revisionasof'           => 'Redaktsij',
'revision-info'          => 'Redaktsij āigald $1 kȭlbatijiz $2 pierrõ',
'previousrevision'       => 'Juo vaņīmi redaktsij',
'nextrevision'           => 'Jo ūž redaktsij',
'currentrevisionlink'    => 'Perri redaktsij',
'cur'                    => 'perri',
'last'                   => 'jedmõli',
'histlegend'             => "Pangid merkid versijõd pǟlõ, midā tōtõ līdzinţõ ja glõbžõgid līdzinţimiz knīepkizt. <br />
Legend: '''({{int:cur}})''' = vaiţīd līdzinţõmizõks lǟndz redaktsijõks,, '''({{int:last}})''' = vaiţīd līdzinţõmizõks jedmiliz redaktsijõks, '''{{int:minoreditletter}}''' = piški mõitõks.",
'history-fieldset-title' => 'Istōrij vaņtlimi',
'history-show-deleted'   => 'Setku jarā kištāntõd',
'histfirst'              => 'Ežmizt',
'histlast'               => 'Perrizt',

# Revision feed
'history-feed-item-nocomment' => '$1 - $2',

# Revision deletion
'rev-delundel'           => 'nägţ/vaŗ jarā',
'revdel-restore'         => 'Mõitiņt nǟdõbõzt',
'revdel-restore-deleted' => 'jarā kištāntõd redaktsijõd',
'revdel-restore-visible' => 'nǟdõbõd redaktsijõd',

# Merge log
'revertmerge' => 'Kīeld jarā kubbõ vieddimi',

# Diffs
'history-title'           => 'Līed "$1" mõitõkst istōrij',
'difference'              => '(Vaiţīd redaktsijõd vail)',
'lineno'                  => 'Rīnda $1:',
'compareselectedversions' => 'Līdzinţ vēļdõt redaktsijḑi',
'editundo'                => 'kištānt jarā',
'diff-multi'              => '({{PLURAL:$1|Īdtõ|$1}} vail-vȯlbizt {{PLURAL:$2|īd|$2}} kȭlbatijiz redaktsijõ äb nägţõbõd.)',

# Search results
'searchresults'                    => 'Vȯtšimiz rezultātõd',
'searchresults-title'              => 'Vȯtšimiz "$1" rezultātõd',
'searchresulttext'                 => 'Mūdõ tieutõkst iļ {{SITENAME}} vȯtšimiz pierāst vaņtligid  [[{{MediaWiki:Helppage}}| opātõksõst]]',
'searchsubtitle'                   => "Vȯtšīztõ frāzõ '''[[:$1]]''' ( [[Special:Prefixindex/$1|amād sõnādõks ''$1'' irgõbõd lēḑõd]]{{int:pipe-separator}} 
[[Special:WhatLinksHere/$1|amād lēḑõd, mis sizzõl um siḑīmḑi kēratõks ''$1'' jūrõ]])",
'searchsubtitleinvalid'            => "Tēg vȯtšīztõ frāzõ  '''$1'''",
'notitlematches'                   => 'Kēratõks pēļikēris vȯtštõd sõņḑi äb ūo lieudtõd',
'notextmatches'                    => 'Kēratõks sizzõl vȯtštõd tekstõ äb lieudtõd',
'prevn'                            => '{{PLURAL:$1|jedmõli|jedmõlizt $1}}',
'nextn'                            => '{{PLURAL:$1|pierrõ-tulbi|pierrõ-tulbizt $1}}',
'prevn-title'                      => '{{PLURAL:$1|Jedmõli rezultāt|Jedmõlizt $1 rezultātõ}}',
'nextn-title'                      => '{{PLURAL:$1|Jedmõli rezultāt|Jedmõlizt $1 rezultātõ}}',
'shown-title'                      => 'Nägţ līed iļ $1 {{PLURAL:$1|rezultāt|rezultātõ}}',
'viewprevnext'                     => 'Nägţõgid ($1 {{int:pipe-separator}} $2) ($3)',
'searchmenu-exists'                => "'''Lēḑ pēļizkēraks \"[[:\$1]]\" um vȯlmizõs.'''",
'searchmenu-new'                   => "'''Lūo lēḑ pēļizkēraks \"[[:\$1]]\".'''",
'searchprofile-articles'           => 'Sižāliz lēḑõd',
'searchprofile-project'            => 'Ab ja projekt lēḑõd',
'searchprofile-images'             => 'Multimēdij',
'searchprofile-everything'         => 'Tikkiž',
'searchprofile-advanced'           => 'Jo akurāt vȯtšimi',
'searchprofile-articles-tooltip'   => 'Vȯtšõgid nim-rūimstõ $1',
'searchprofile-project-tooltip'    => 'Vȯtšõgid nim-rūimstõ $1',
'searchprofile-images-tooltip'     => 'Fail vȯtšimi',
'searchprofile-everything-tooltip' => 'Vȯtšõgid amā sižāliz sizāld (ka nõvpidāmiz-lēḑõd pǟld)',
'searchprofile-advanced-tooltip'   => 'Vȯtšõgid andtõd nim-rūimšti',
'search-result-size'               => '$1 ({{PLURAL:$2|1 sõnā|$2 sõnnõ}})',
'search-result-category-size'      => '{{PLURAL:$1|1 lēḑ|$1 līedpūoltõ}} ({{PLURAL:$2|1 alīz-kategōrij|$2 alīzt kategōrijõ}}, {{PLURAL:$3|1 fail|$3 failõ}})',
'search-redirect'                  => '($1 jeddõpēḑõn sōtimi)',
'search-section'                   => '(alli jag $1)',
'search-suggest'                   => 'Kas mõtliztõ: $1',
'search-interwiki-caption'         => 'Sõzār-projektõd',
'search-interwiki-default'         => '$1 rezultātõd:',
'search-interwiki-more'            => ' (vel)',
'search-mwsuggest-enabled'         => 'jeddõpandõkstõks',
'search-mwsuggest-disabled'        => 'jeddõpandõkši äb ūo',
'searchrelated'                    => 'sidtõd',
'searchall'                        => 'tikkiž',
'showingresultsheader'             => "{{PLURAL:$5|'''$1''' '''$3'''-st rezultātõst|Rezultātõd '''$1–$2''' '''$3'''-st}} kizzimizõn '''$4'''",
'nonefound'                        => "'''Pangid tǟdõl''': Vȯtšõbõd set mingizt nim-rūimõd sizāld. Až tēg tōgid vȯtšõ amšti nim-rūimšti (ka nõvpidāmiz lēḑõd, mallõd, jnj sizāld) kȭlbatõgid kizzimiz jedsõ prefiksõ ''all:''",
'search-nonefound'                 => 'Vȯtšimizõn vȯtšimi äb lieudtõd vastūkst.',
'powersearch'                      => 'Juo akurāt vȯtšimi',
'powersearch-legend'               => ' Juo akurāt vȯtšimi',
'powersearch-ns'                   => 'Vȯtšimi nim-rūimšti:',
'powersearch-redir'                => 'Jeddõpēḑõn sōtimizt nimkēra',
'powersearch-field'                => 'Vȯtšõgid frāzõ',

# Preferences page
'preferences'             => 'Mīeldõbõd ulzõ-vēļimizt',
'mypreferences'           => 'Min mīeldõbõd ulzõ-vēļimizt',
'youremail'               => 'E-kēra adres:',
'yourrealname'            => 'Õigi nim:',
'prefs-help-email'        => 'E-kēra adres sīezõ-panmi äb ūo käsktõd, bet se laskūb täddõn teļļõ sallisõnā määdõltõks, až tēg unūţ eņtš sallisõnā jarā.',
'prefs-help-email-others' => 'Võigõd ka pallõ tuoiztõn sin kȭlbatijiz- agā nõvpidāmiz-līeds tädkõks kontakt võttõ, sīe azmõl, ku täddõn vȯlkõ vajāg eņtš ummidi tieutidi nägţõ',

# Groups
'group-sysop' => 'Administrātord',

'grouppage-sysop' => '{{ns:project}}:Administrātord',

# User rights log
'rightslog' => 'Kȭlbatijiz õigõmt log',

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'siedā līedtõ mõitiņtõ',

# Recent changes
'nchanges'                        => '$1 {{PLURAL:$1|mõitõks|mõitõkst}}',
'recentchanges'                   => 'Perrizt mõitõkst',
'recentchanges-legend'            => 'Perrizt mõitõkst',
'recentchangestext'               => 'Vaņ sīe līed pǟl tīedõd perīži mõitõkši.',
'recentchanges-feed-description'  => 'Vaņ iļ vikipēdijõz tīedõd perīži mõitõkši.',
'recentchanges-label-newpage'     => 'Se mõitõks luoi ūd līed',
'recentchanges-label-minor'       => 'Se um ikš piški parāmtimi',
'recentchanges-label-bot'         => 'Sīe mõitõks tei ikš robot',
'recentchanges-label-unpatrolled' => 'Se mõitõks tēji vȯļ ikš robot',
'rcnote'                          => "Allõ-pūol um andtõd {{PLURAL:$1| '''1''' mõitõks|'''$1''' mõitõks}} perīz {{PLURAL:$2|pǟva|'''$2''' pǟva}}, āigal kēratõd $5 kīela $4.",
'rcnotefrom'                      => "Allõ-pūol um tūodõd mõitõkst  '''$2''' sōņõst: (nägţõbõd amā jemīņ '''$1''' mõitõkst)",
'rclistfrom'                      => 'Nägţ mõitõkši sōņõst: $1',
'rcshowhideminor'                 => '$1 piškizt parāmtimizt',
'rcshowhidebots'                  => '$1 robōtõd',
'rcshowhideliu'                   => '$1 sīezõ loggõnd kȭlbatijizt',
'rcshowhideanons'                 => '$1 bäz nimmõ kȭlbatijizt',
'rcshowhidepatr'                  => '$1 vaņtlõd mõitõkst',
'rcshowhidemine'                  => '$1 min parāmtimizt',
'rclinks'                         => 'Nägţ perīži $1 mõitõkši lǟndz $2 pǟva āigal <br />$3',
'diff'                            => 'vaiţ',
'hist'                            => 'istōrij',
'hide'                            => 'Vaŗ jarā',
'show'                            => 'Nägţ',
'minoreditletter'                 => 'p',
'newpageletter'                   => 'N',
'boteditletter'                   => 'b',
'rc-enhanced-expand'              => 'Nägţ jo akurātidi ažḑi (Javascriptõ um vajāg)',
'rc-enhanced-hide'                => 'Vaŗ jarā',

# Recent changes linked
'recentchangeslinked'          => 'Sidtõd mõitõkst',
'recentchangeslinked-toolbox'  => 'Sidtõd mõitõkst',
'recentchangeslinked-title'    => '"$1" sidtõd mõitõkst',
'recentchangeslinked-noresult' => 'Andtõd āigal äb ūo sidtõd lēḑis mõitõkši tīedõd.',
'recentchangeslinked-summary'  => "Täs um lugdõd andtõd līedstõ sidtõd (agā andtõd kategōrij) lēḑis tīedõd perrizt mõitõkst. Sin [[Special:Watchlist|iļ-vaņtlimiz.nimkēra]] lēḑõd ātõ  ' ' ' razzistiz ' ' ' jeddõ tūodõd.",
'recentchangeslinked-page'     => 'Līed nim:',
'recentchangeslinked-to'       => 'Nägţ sīe azmõl mõitõkši lēḑis, mis sīen līed pǟlõ sidābõd',

# Upload
'upload'        => 'Fail ilzõ-lōţimi',
'uploadlogpage' => 'Ilzõ-lōţimiz log',
'filedesc'      => 'Kubbõ võtāmi:',
'uploadedimage' => 'lōţiz ilzõ fail "[[$1]]"',

'license'        => 'Litsents:',
'license-header' => 'Litsents:',

# File description page
'file-anchor-link'          => 'Bīlda',
'filehist'                  => 'Fail istōrij',
'filehist-help'             => 'Glõbžõgid kūpǟva ja kīela-aigõ, laz nǟdõg sīesõ āigal kȭlbatõd vȯnnõd fail versijõ.',
'filehist-revert'           => 'kīerõgid tāgiž',
'filehist-current'          => 'perri',
'filehist-datetime'         => 'Kūpǟva/Kīela-āiga',
'filehist-thumb'            => 'Piški bīlda',
'filehist-thumbtext'        => 'Piški bīlda $1 versijõst',
'filehist-user'             => 'kȭlbatiji',
'filehist-dimensions'       => 'Sūrit',
'filehist-comment'          => 'Komentār',
'imagelinks'                => 'Fail kȭlbatõmi',
'linkstoimage'              => 'Sīen bīldan {{PLURAL:$1|sidūb se lēḑ|$1 sidābõd ne lēḑõd}}:',
'nolinkstoimage'            => 'Äbmingi lēḑ äb sidā sīe bīlda pǟlõ',
'sharedupload'              => 'Se fail um võttõd ovātõst $1 ja siedā võib vȱlda kȭlbatõd ka mūši projektis.',
'sharedupload-desc-here'    => 'Se um jaggõt fail ovātõst $1 ja siedā sōb kȭlbatõ ka mūši projektis. Fail sǟl vȯlbi [$2 seļţimi] um nägţõd allõ-pūol.',
'uploadnewversion-linktext' => 'Lōţõgid ilzõ sīe fail ūž versij',

# Random page
'randompage' => 'Bäz tīedõmõt tulbõ kēratõks',

# Statistics
'statistics' => 'Lug tīetõkst',

'disambiguationspage' => 'Template:Jarā-seļţimiz-lēḑ',

# Miscellaneous special pages
'nbytes'        => '$1 {{PLURAL:$1|bait|baitõ}}',
'nmembers'      => '$1 {{PLURAL:$1|nõtkõm| nõtkõmḑi}}',
'prefixindex'   => 'Amād pēļikērad prefiksõks',
'usercreated'   => 'Konto {{GENDER:$3|lūomiz}} āiga: $1 kīela $2',
'newpages'      => 'Ūd lēḑõd',
'move'          => 'Vīž',
'movethispage'  => 'Viedāgid se līedpūol tuoiz nim alā',
'pager-newer-n' => '{{PLURAL:$1|jo ūž 1|jo ūd $1}}',
'pager-older-n' => '{{PLURAL:$1|jo vaņīmi 1|jo vaņīmizt $1}}',

# Book sources
'booksources'               => 'Rōntõ vȯtšimi',
'booksources-search-legend' => 'Rōntõ vȯtšimi',
'booksources-go'            => 'Li',

# Special:Log
'log' => 'Logūd',

# Special:AllPages
'allpages'       => 'Amād lēḑõd',
'alphaindexline' => '$1 sōņist $2 sōņõ',
'prevpage'       => 'Jedmõli lēḑ ($1)',
'allpagesfrom'   => ' Nägţ līedidi pēļizkērast sōņõst:',
'allpagesto'     => ' Nägţ līedidi sīe pēļikēra sōņõ:',
'allarticles'    => 'Amād lēḑõd',
'allpagessubmit' => 'Li',

# Special:Categories
'categories' => 'Kategōrijõd',

# Special:LinkSearch
'linksearch'      => 'Uļļizt siḑīmõd',
'linksearch-line' => '$1 um sidtõd līedst $2',

# Special:Log/newusers
'newuserlogpage' => 'Kȭlbatijizt lūomiz log',

# Special:ListGroupRights
'listgrouprights-members' => '(nõtkõmd nimkēra)',

# E-mail user
'emailuser' => 'Sōtõgid sīen kȭlbatijizõn e-kēra',

# Watchlist
'watchlist'         => 'Iļ-vaņtlimiz nimkēra',
'mywatchlist'       => 'Min iļ-vaņtlimiz nimkēra',
'watchlistfor2'     => 'Kȭlbatijiz $1 ($2) pierāst',
'addedwatchtext'    => "Lēḑ \"[[:\$1]]\" um sin [[Special:Watchlist|iļ-vaņtlimiz nimkērrõz]] jūrõ pandõd. Jeddõpēḑõn tulbõd mõitõkst sīe līed pǟl ja sīenkõks sidtõd nõvpidāmiz-līed pǟl sugõbõd iļ-vaņtlimiz nimkērrõz  āt [[Special:RecentChanges|perrizt mõitõkst līed pǟl]]  kēratõd  '''razīz''' kēraks.",
'removedwatchtext'  => 'Lēḑ "[[:$1]]" um [[Special:Watchlist|iļ-vaņtlimiz nimkērast]] jarā viedtõd.',
'watch'             => 'Vaņtligid iļ sīe',
'watchthispage'     => 'Vaņ iļ siedā līedpūoltõ',
'unwatch'           => 'Lopta iļ-vaņtlimi',
'watchlist-details' => ' {{PLURAL:$1|$1 lēḑ|$1 līedtõ}} ātõ iļ-vaņtlimiz nimkēras,  bäz luggõmõt nõvpidāmiz-līedidi.',
'wlshowlast'        => 'Nägţ perīzt $1 stuņdõ $2 päuvõ $3',
'watchlist-options' => 'Iļ-vaņtlimiz nimkēra pie-lēmizt',

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Vaņtlimi iļ sīe...',
'unwatching' => 'Iļ-vaņtlimiz loptimi...',

# Delete
'deletepage'            => 'Kištāntõgid se lēḑ jarā',
'confirmdeletetext'     => 'Tēg tōtõ datubāzõst igāniz jarā kištāntõ līedtõ agā bildõ īdskubs amā täm istōrijõks. Pōlaks tȭitagid, ku tēg tōtõ siedā tuodīstiz tīedõ ja ku tēg mūoštagid rezultātidi ja ku täd tīemi um täs õigistiz [[{{MediaWiki:Policy-url}}|sizāļiz kȭrda pierrõ]].',
'actioncomplete'        => 'Ažā tīedõd',
'actionfailed'          => 'Tīemi äb-vȯņštīz',
'deletedtext'           => ' "$1" um jarā kištāntõd. Jarā kištāntõd lēḑõd āt tūodõd nimkēras $2.',
'dellogpage'            => 'Jarā kištāntimiz log',
'deletecomment'         => 'Sī:',
'deleteotherreason'     => 'Mū agā jūrõ pandõb sī:',
'deletereasonotherlist' => 'Mū sī',

# Rollback
'rollbacklink' => 'kīeld jarā (tūo tāgiž)',

# Protect
'protectlogpage'              => 'Kaitsõmiz log',
'protectedarticle'            => 'kāitsiz līed "[[$1]]"',
'modifiedarticleprotection'   => 'mõitiņtīz līed "[[$1]]" kaitsõmiz ildõmt',
'protectcomment'              => 'Sī:',
'protectexpiry'               => 'Lopūb:',
'protect_expiry_invalid'      => 'Äbkȭlbatõb loppõmiz āiga.',
'protect_expiry_old'          => ' Loppõmiz āiga um lǟndzāigas.',
'protect-text'                => "Täs võid vaņtlõ ja mõitiņtõ līed '''$1''' kaitsõmiz-ildõmt.",
'protect-locked-access'       => "Täddõn äb ūo õigõmt mõitiņtõ līed kaitsõmiz-ildõmt.   Allõ-pūol ātõ līed '''$1''' paldīž joūdõs vȯlbizt ulzõ-vēļimizt:",
'protect-cascadeon'           => 'Se lēḑ um kaitstõd, sīepierāst ku tǟnda um kȭlbatõd {{PLURAL:$1|page, which has|pages, which have}}  {{PLURAL:$1|sīesõ līeds, |lēḑis}}   {{plural:$1| sīesõ līeds| nēši  lēḑis}}, mis ātõ īž kaskād kaitsõmiz allõ. Sa sōd mõitiņtõ sīe līed kaitsõmizt, bet se äb mõitiņt kaskād kaitsõmizt.',
'protect-default'             => 'Āndagid lubā āmādõn kȭlbatijiztõn',
'protect-fallback'            => 'Ma tōb "$1" õigõmḑi',
'protect-level-autoconfirmed' => 'Blokīerõgid ūd ja bäz pa-kēratõmõt kȭlbatijizt',
'protect-level-sysop'         => 'Setku administrātord',
'protect-summary-cascade'     => ' kaskād',
'protect-expiring'            => ' lopūb $1 (UTC)',
'protect-cascade'             => 'Kaitsõgid līedidi, mis um sidtõd sīe līed jūrõ (kaskād-kaitsõmizõks)',
'protect-cantedit'            => 'Sa äd sō līed kaitsõmiz ildõmt mõitiņtõ, sīestõ ku sinnõn pūtõbõd līed redigīerimiz õigõmd.',
'restriction-type'            => 'Lubād:',
'restriction-level'           => 'Kaitsõmiz ildõm:',

# Undelete
'undeletelink'     => 'vaņ/lūo ūtstõ',
'undeleteviewlink' => 'vaņ',

# Namespace form on various pages
'namespace'      => 'Nim-rūim:',
'invert'         => 'Tīegid selektsij dagāržpēḑõn',
'blanknamespace' => '(Kēratõkst)',

# Contributions
'contributions'       => 'Kȭlbatijiz kubsõtīe',
'contributions-title' => 'Kȭlbatijiz $1 kubsõtīe',
'mycontris'           => 'Min kubsõtīed',
'contribsub2'         => 'Kȭlbatiji $1 ($2) pierāst',
'uctop'               => '(tutkāms)',
'month'               => ' Kūstõ sōņist (un jo vārald)',
'year'                => 'āigastõst',

'sp-contributions-newbies'  => 'Nägţ setku ūd kȭlbatijizt kubsõtīed',
'sp-contributions-blocklog' => 'blokīerimizt',
'sp-contributions-uploads'  => 'ilzõ-lōţimizt',
'sp-contributions-logs'     => 'logūd',
'sp-contributions-talk'     => 'Nõvpidāmi',
'sp-contributions-search'   => 'Kubsõtīe vȯtšimi',
'sp-contributions-username' => 'IP adres agā kȭlbatijiznim:',
'sp-contributions-toponly'  => 'Setku amā ūd redaktsijõd',
'sp-contributions-submit'   => 'Vȯtšõgid',

# What links here
'whatlinkshere'            => 'Siḑīmõd tǟnõ',
'whatlinkshere-title'      => ' Lēḑõd, mis sidābõd lēḑ  "$1" pǟlõ',
'whatlinkshere-page'       => 'Lēḑ:',
'linkshere'                => "Līed  '''[[:$1]]''' pǟlõ sidābõd ne lēḑõd:",
'nolinkshere'              => "Līed '''[[:$1]]''' pǟlõ äb ūo sidtõd mittikš lēḑ.",
'isredirect'               => 'jeddõpēḑõn sōtimiz lēḑ',
'istemplate'               => 'kȭlbatõmi mallõks',
'isimage'                  => 'Siḑīm fail jūrõ',
'whatlinkshere-prev'       => '{{PLURAL:$1|jedmõli|jedmõlizt $1}}',
'whatlinkshere-next'       => '{{PLURAL:$1|pierrõ-tulbi|pierrõ-tulbizt $1}}',
'whatlinkshere-links'      => '← siḑīmõd',
'whatlinkshere-hideredirs' => '$1 jeddõpēḑõn sōtimizt',
'whatlinkshere-hidetrans'  => '$1 mallõks kȭlbatõmizt',
'whatlinkshere-hidelinks'  => '$1 siḑīmõd',
'whatlinkshere-hideimages' => '$1 bīldaks siḑīmõd',
'whatlinkshere-filters'    => 'Sõggõld',

# Block/unblock
'blockip'                  => 'Kȭlbatijiz blokīerimi',
'ipboptions'               => ' 2 stuņdõ:2 hours,1 pǟva:1 day,3 päuvõ:3 days,1 nädīļ:1 week,2 nädīļt:2 weeks,1 kū:1 month,3 kūdõ:3 months,6 kūdõ:6 months,1 āigast:1 year,iggi:infinite',
'ipblocklist'              => 'Jarā kīeldtõd kȭlbatijizt',
'blocklink'                => 'blokīer',
'unblocklink'              => 'lopta blokīerimi',
'change-blocklink'         => 'mõitiņt blokīerimizt',
'contribslink'             => 'kubsõtīe',
'blocklogpage'             => 'Blokīerimiz log',
'blocklogentry'            => 'Blokīerimiz kȭlbatijiz [[$1]], jarā loppõmiz āiga um $2 $3',
'unblocklogentry'          => 'võtiz jarā kȭlbatijiz $1 blokīerimiz',
'block-log-flags-nocreate' => 'kontod lūomi um kīeldtõd',

# Move page
'movepagetext'     => "Siedā formõ kȭlbatõs sōtõ līed tuoizõks nimtõ. Līed istōrij nustõbõd ūd pēļikēra alā automātlistiz. Paldīž-vȯļļijiz pēļizkēraks līedst sōb jeddõpēḑõn sōtimiz lēḑ ūd līedpūol jūrõ. Sōd jedmõļiz pēļikēra jūrõ sidābõd jeddõpēḑõn sōtimizt automātlistiz parāntõ. Až tēg siedā äb tīend, vaņtlõgid lebbõ, ku jarā vīmiz pierāst ūo īenõd pāikal [[Special:DoubleRedirects|kōd-kȭrdaliži]] äbkā [[Special:BrokenRedirects|kaţkiži jeddõpēḑõn sōtimiži]].
Sin ilzandõks um ūoļikšõ sīe jedstõ, ku amād ažād īebõd strōdõm, nemē jeddõ nǟdõt. Pan tǟdõl, ku līetõ '''äb vībõd''' jeddõpēḑõn  siz, až ūd pēļizkēraks līedpūol um jubā vȯlmizõs, bäz luggõmõt až vȯlmizõs līedpūol um tijā agā bäz redigīerimiz istōrijõ jeddõpēḑõn sōtimiz lēḑ. 
Se tǟntõb, ku äb sō iļ kēratõ jubā vȯlmizõs līedpūoltõ, bet sōb äbvȯņštõn ūtstõ nimtimiz tāgiž kīerõ. 

'''Kūondõks!''' Se võib vȱlda lugdõb līed jūs ikš väggi tuožžī ja bäz vȯdlõmõt mõitõks; jedmõl jatkimizt pōlaks mõtlõgid iļ rezultātõd.",
'movepagetalktext' => "Īdskubs kēratõks līedkõks sōtõbõd jeddõpēḑõn automātlistiz ka nõvpidāmiz-lēḑ, '''bäs.luggõmõt siz, až:''' 
* ūd pēļikēra allõ um jubā nõvpidāmiz-lēḑ, mis äb.ūo tijā;
* tēg jetīztõ allõ vȯlbiz merk rūţ bäz vēļõmõt. 
Až sugīz nei, sōd līed tōdõs kädūdõks jeddõpēḑõn sōtõ agā jūrõ-pānda.",
'movearticle'      => 'Sōtõgid se lēḑ jeddõpēḑõn',
'newtitle'         => 'Ūd pēļizkēra alā:',
'move-watch'       => 'Vaņ iļ siedā līedtõ',
'movepagebtn'      => 'Sōtõgid se lēḑ jeddõpēḑõn',
'pagemovedsub'     => 'Lēḑ um jeddõpēḑõn sōtõd',
'movepage-moved'   => '\'\'\'"$1" um jeddõpēḑõn sōtõd "$2"alā\'\'\'',
'articleexists'    => 'Sīe nimkõks kēratõks um jubā vȯlmizõs agā täd vēļdõt nim um äbkȭlbatõb. Pōlaks vēļõgid ūž nim.',
'talkexists'       => "'''Lēḑ um jeddõpēḑõn sōtõd, bet nõvpidāmiz-līedtõ äb sōnd jeddõpēḑõn sōtõ, sīestõ ku ūd nim allõ um nõvpidāmiz-lēḑ jubā vȯlmizõs. Pōlaks viedāgid nõvpidāmiz-lēḑõd īž kubbõ.'''",
'movedto'          => 'Jeddõpēḑõn sōtõd pēļizkēra alā:',
'movetalk'         => 'Sōtõgid jeddõpēḑõn ka nõvpidāmiz lēḑ',
'movelogpage'      => 'Jarā vīmiz log',
'movereason'       => 'Sī:',
'revertmove'       => 'kīerõgid tāgiž',

# Export
'export' => 'Lēḑõd eksport (ulzõ-vīmi)',

# Namespace 8 related
'allmessagesname'    => 'Nim',
'allmessagesdefault' => 'Vāgiž-vȯlmiz tekst',

# Thumbnails
'thumbnail-more'  => 'Sūriņţ',
'thumbnail_error' => 'Vigā piškiz bīlda lūomizõs: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'             => 'Sin kȭlbatijiz lēḑ',
'tooltip-pt-mytalk'               => 'Täd nõvpidāmiz lēḑ',
'tooltip-pt-preferences'          => 'Min mīeldõbõd ulzõ-vēļimizt',
'tooltip-pt-watchlist'            => 'Lēḑõd nimkēra, mis iļ vaņtlõd mõitõkši',
'tooltip-pt-mycontris'            => 'Sin kubsõtīed nimkēra',
'tooltip-pt-login'                => 'Mēg panām jeddõl tēḑi sīezõ kēratõm, bet siedā äb ūo vajāg',
'tooltip-pt-logout'               => 'Log ulzõ',
'tooltip-ca-talk'                 => 'Nõvpidāmi sīe kēratõks iļ',
'tooltip-ca-edit'                 => 'Sōd siedā līedpūoltõ redigīerõ. Pōlaks kȭlbatõgid jeddõ-vaņtlimizt jedmõl sa-gläbbõmizt',
'tooltip-ca-addsection'           => 'Pan jūrõ ūž alli-jag',
'tooltip-ca-viewsource'           => 'Se līedpūol um kaitstõd. Sōd vaņtlõ sīe ovāt-tekstõ',
'tooltip-ca-history'              => 'Sīe līedpūol jedmõļizt versijõd',
'tooltip-ca-protect'              => 'Kaitsõgid siedā līedtõ',
'tooltip-ca-delete'               => ' Kištānt jarā se lēḑ',
'tooltip-ca-move'                 => 'Vīž se līedpūol tuoiz nim alā',
'tooltip-ca-watch'                => 'Pan jūrõ se līedpūol eņtš iļ-vaņtlimiz nimkerrõ',
'tooltip-ca-unwatch'              => 'Viedāgid jarā se līedpūol eņtš iļ-vaņtlimiz nimkērast',
'tooltip-search'                  => 'Vȯtšõgid līedtõ {{SITENAME}}',
'tooltip-search-go'               => 'Li kūoḑõn seļļiz pēļizkēraks līed pǟlõ (až seļļi um vȯlmizõs)',
'tooltip-search-fulltext'         => 'Vȯtšõbõd kēratõkši, mis sizzõl um se lugāndõks',
'tooltip-p-logo'                  => 'Li eḑīz līed pǟlõ',
'tooltip-n-mainpage'              => 'Li eḑīz līed pǟlõ',
'tooltip-n-mainpage-description'  => 'Li eḑīz līed pǟlõ',
'tooltip-n-portal'                => 'Iļ projekt, midā tīedõ sōd, kui um ažḑi lieudõmist',
'tooltip-n-currentevents'         => 'Līeda tieutõkst iļ paldīž suggõbõd ažād',
'tooltip-n-recentchanges'         => 'Vikipēdijs tīedõd perrizt mõitõkst nimkēra',
'tooltip-n-randompage'            => 'Li bäz tīedõmõt tulbõ līed pǟlõ',
'tooltip-n-help'                  => 'Kūož laz lieudõg ilzõ',
'tooltip-t-whatlinkshere'         => 'Amād vikipēdij lēḑõd, kust um tǟnõ siḑīmḑi',
'tooltip-t-recentchangeslinked'   => 'Perrizt mõitõkst lēḑis, missõn um täst siḑīmḑi',
'tooltip-feed-rss'                => 'Sīe līedpūol RSS sīeţ',
'tooltip-feed-atom'               => 'Sīe līed Atom sīeţ',
'tooltip-t-contributions'         => 'Nägţ sīe kȭlbatijiz kubsõtīe',
'tooltip-t-emailuser'             => 'Sōtõgid sīen kȭlbatijizõn e-kēra',
'tooltip-t-upload'                => 'Fail ilzõ-lōţimi',
'tooltip-t-specialpages'          => 'Eņtšvīţizt lēḑõd nimkēra',
'tooltip-t-print'                 => 'Sīe līed drukkimiz versij',
'tooltip-t-permalink'             => 'Iggi siḑīm līed sīen versij pǟlõ',
'tooltip-ca-nstab-main'           => 'Nägţ kēratõkst',
'tooltip-ca-nstab-user'           => 'Nägţ kȭlbatijiz līedtõ',
'tooltip-ca-nstab-special'        => ' Se um ikš eņtšvīţi lēḑ, tēg ät sōtõ siedā redigīerõ',
'tooltip-ca-nstab-project'        => 'Nägţ projekt līedtõ',
'tooltip-ca-nstab-image'          => 'Nägţ bīlda līedtõ',
'tooltip-ca-nstab-template'       => 'Nägţ mallõ',
'tooltip-ca-nstab-category'       => 'Nägţ kategōrij līedtõ',
'tooltip-minoredit'               => 'Pangid tǟnõ merk ku se um ikš piški parāmtimi',
'tooltip-save'                    => 'Sa-gläbb mõitõkst',
'tooltip-preview'                 => 'Nägţ tīedõd mõitõkši. Pōlaks kȭlbatigid siedā jedmõl sa-gläbbõmizt!',
'tooltip-diff'                    => 'Nägţ tīedõd mõitõkši.',
'tooltip-compareselectedversions' => 'Nägţ vaiţidi kōd sīe līed vēļdõt versijõ vail',
'tooltip-watch'                   => 'Pan jūrõ se līedpūol eņtš iļ-vaņtlimiz nimkerrõ',
'tooltip-rollback'                => 'Kištāntõb jarā īd glõbžõks lǟndz kubsõtīe tējiz tīedõd mõitõkst',
'tooltip-undo'                    => '"Viedāgid jarā" tīeb tijāks/kīeldõbjarā sīe mõitõks ja ovātõb redigīerimiz läb tekstõ jedmõl-vaņtlimizõks. Neiīž tēg võigid sǟl kēratõ, mis vȯļ sīe jarā vīmiz sī.',
'tooltip-summary'                 => 'Kēratigid lītõ kubbõ-võtāmi',

# Browsing diffs
'previousdiff' => '← Jedmõli redaktsij',
'nextdiff'     => 'Jo ūd redigīerimizt',

# Media information
'file-info-size' => ' $1 × $2 piksõlt, bildā sūrit: $3, MIME tīp: $4',
'file-nohires'   => 'Sīestõ sūrimmõ bildõ äb ūo.',
'svg-long-desc'  => 'SVG fail, origināli sūrit  $1 × $2 piksõlt, fail sūrit: $3',
'show-big-image' => 'täuž rezolūtsij',

# Bad image list
'bad_image_list' => 'Tǟdõl panābõd setku nimkēra elementõd ( rīndad, mis irgõbõd simbōlõks *) . Ežmi siḑīm rīndas um kilāb siḑīm äbkȭlbatõb fail jūrõ. Sīel īž rīndas vȯlbiži pierrõ tulbiži siḑīmḑi vaņtlõbõd nemē mūšti ulzõ võtāmiži, se tǟntõb kēratõkši, mis jūrõ failõ võib pānda.',

# Metadata
'metadata'          => 'Meta-tīetõkst',
'metadata-help'     => 'Se fail sizzõl um mūdõ tieutõkst, mis um kilāb jūrõ-pand digikāmera agā skannõr pūolst. Až failõ um eņtšvīţiz programmatūraks kȭlbatõd, võib setmin tieutidi vȱlda mõitiņtõd agā tikkiž jarā kištāntõd',
'metadata-expand'   => 'Nägţ mūḑi jo akurātidi ažḑi',
'metadata-collapse' => 'Vaŗ jarā juo akurāt ažād',
'metadata-fields'   => 'Täs lugdõd fail meta-tīetõkst vellidi nägţõbõd bīlda seļţimiz līeds meta-tīetõkst vaņtlimiz āigal. Munt tīetõkst ātõ bäz kītõmõt jarā vaŗtõd. 
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength
* artist
* copyright
* imagedescription
* gpslatitude
* gpslongitude
* gpsaltitude',

# External editor support
'edit-externally'      => 'Protseššõgid failõ ulīz programmatūraks',
'edit-externally-help' => '(Vaņ uļļizt redaktōrd adresõs [//www.mediawiki.org/wiki/Manual:External_editors setup instructions] kȭlbatõmiz opātõkst)',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'tikkiž',
'namespacesall' => 'tikkiž',
'monthsall'     => 'tikkiž',

# Watchlist editing tools
'watchlisttools-view' => 'Nägţ sīe mõitõkši',
'watchlisttools-edit' => 'Vaņ ja redigīer iļ-vaņtlimiz nimkerrõ',
'watchlisttools-raw'  => 'Mõitiņt ovāt-tekstõ',

# Core parser functions
'duplicate-defaultsort' => "'''Kūondõks:''' Kõõrda-jadā võţīm ''$2'' tīeb tijāks jedsõ pūol vólbiz kõõrda-jadā võţīm ''$1''.",

# Special:SpecialPages
'specialpages' => 'Eņtšvīţizt lēḑõd',

# External image whitelist
'external_image_whitelist' => '  #Jettõgid se jadā bäz mõitiņtõmõt<pre>
#Pangid regulār-ekpressij jagūd ( set merkid // vail vȯlbi jag) mōzõpēḑõn 
#Ne āt sidtõd vikipēdij-uļļizt bīldad internet adresõdõks
#Sidtõd vȯlbizt nägţõbõd bīldadõks, mūn kȭrdal nägţõbõd setku bīlda siḑīm 
#Merkõks # irgõbõd rīndad āt komentārd 
#Se um nei-īž sūrd ja piškizt tǟdõdõks

#Pangid tikkiž regulār-ekpressij jagūd sīe krīpš pāikal. Jettõgid se jadā bäz mõitiņtõmõt mūoḑ pǟlõ  </pre>',

# Special:Tags
'tag-filter' => '[[Special:Tags|Tag]] sõggõl:',

);
